<p align="center">
    <a target="_blank" href='https://url.cn/Z4lzPLaF'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/ads%2F1040x100-tencent.jpg" width="100%"/>
    </a>   
</p>
<p align="center">
    <a target="_blank" href='https://github.com/CoderWanFeng/python-office'>
    <img src="https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/github-nav.jpg" alt="github license"/>
    </a>   
</p>
<p align="center">
	👉 <a target="_blank" href="https://www.python-office.com/">项目官网：https://www.python-office.com/</a> 👈
</p>
<p align="center">
	👉 <a target="_blank" href="https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office.jpg">本开源项目的交流群</a> 👈
</p>
<p align="center" name="gitee">
  <a target="_blank" href='https://github.com/CoderWanFeng/python-office'>
    <img src="https://img.shields.io/github/stars/CoderWanFeng/python-office.svg?style=social" alt="github star"/>
    </a>
	<a target="_blank" href='https://gitee.com/CoderWanFeng/python-office/'>
		<img src='https://gitee.com/CoderWanFeng/python-office/badge/star.svg?theme=dark' alt='gitee star'/>
	</a>
  	<a href="https://mp.weixin.qq.com/s/yaSmFKO3RrBpyanW3nvRAQ">
	<img src="https://img.shields.io/badge/QQ-163434413-orange"/>
  </a>
    	<a href="https://mp.weixin.qq.com/s/wx-JkgOUoJhb-7ZESxl93w">
	<img src="https://img.shields.io/badge/%E5%BE%AE%E4%BF%A1-%E4%BA%A4%E6%B5%81%E7%BE%A4-brightgreen"/>
  </a>
  
</p>





-------------------------------------------------------------------------------

[**🌎English Documentation**](README-EN.md)

-------------------------------------------------------------------------------

## 📚简介

Python-office 是一个 Python 自动化办公第三方库，能解决大部分自动化办公的问题。而且每个功能只需一行代码，不需要小白用户学习 Python 知识，做到了真正的开箱即用。
> 功能持续更新中，提交你的功能需求/参与项目开发，联系👉[开发者微信](https://mp.weixin.qq.com/s/FgKB-9XEG_KunLfjJbvdYw)


![](https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office-qr.jpg)
### 🍺特点
- 一键搭建所有 Python + 自动化办公的编程环境。
- 使用一行代码解决大部分自动化办公的问题，不需要小白学习 Python 知识
- 贴合职场办公需求
- 极简编程，学习成本极低，工作效率提升显著


-------------------------------------------------------------------------------

## 📦安装

### 🍊pip 自动下载&更新

```
pip install -i https://mirrors.aliyun.com/pypi/simple/ python-office -U
```


-------------------------------------------------------------------------------

## 📝文档

[📘官网：https://www.python-office.com/](https://www.python-office.com/)

全部功能的说明

- 文字教程👉[传送门](https://www.python-office.com/guide/allFunc.html)

- 视频教程👉[传送门](https://www.python-office.com/video/video.html)


## 🛠️包含组件

以下所有功能，都在逐步搭建中。

| 模块                   |     介绍                                                                          |GitHub地址| star|
| ----------------------|---------------------------------------------------------------------------------- |-----|-----|
| PyOfficeRobot                   |     聊天机器人                                                        | https://github.com/CoderWanFeng/PyOfficeRobot |<img src="https://img.shields.io/github/stars/CoderWanFeng/PyOfficeRobot.svg" alt="github star"/>|
| search4file                   |     文档搜索                                                        | https://github.com/CoderWanFeng/search4file |<img src="https://img.shields.io/github/stars/CoderWanFeng/search4file.svg" alt="github star"/>|
| poexcel                 |     excel处理                                              |https://github.com/CoderWanFeng/poexcel |<img src="https://img.shields.io/github/stars/CoderWanFeng/poexcel.svg" alt="github star"/>|
| poword                  |     word处理                                              |https://github.com/CoderWanFeng/poword |<img src="https://img.shields.io/github/stars/CoderWanFeng/poword.svg" alt="github star"/>|
| poppt                   |     ppt处理                                                                     |https://github.com/CoderWanFeng/poppt |<img src="https://img.shields.io/github/stars/CoderWanFeng/poppt.svg" alt="github star"/>|
| popdf                   |     pdf处理                                              |https://github.com/CoderWanFeng/popdf |<img src="https://img.shields.io/github/stars/CoderWanFeng/popdf.svg" alt="github star"/>|
| pofile                  |     文件和文件夹的操作                                          |https://github.com/CoderWanFeng/pofile |<img src="https://img.shields.io/github/stars/CoderWanFeng/pofile.svg" alt="github star"/>|
| wftools                 |     便捷小工具                                        |https://github.com/CoderWanFeng/wftools |<img src="https://img.shields.io/github/stars/CoderWanFeng/wftools.svg" alt="github star"/>|
| poimage                 |     图片处理            |https://github.com/CoderWanFeng/poimage |<img src="https://img.shields.io/github/stars/CoderWanFeng/poimage.svg" alt="github star"/>|
| povideo                 |     视频处理                                          |https://github.com/CoderWanFeng/povideo |<img src="https://img.shields.io/github/stars/CoderWanFeng/povideo.svg" alt="github star"/>|
| pydatav                 |     数据可视化                                          |https://github.com/CoderWanFeng/pydatav |<img src="https://img.shields.io/github/stars/CoderWanFeng/pydatav.svg" alt="github star"/>|
| potime                 |     时间工具                                          |https://github.com/CoderWanFeng/potime |<img src="https://img.shields.io/github/stars/CoderWanFeng/potime.svg" alt="github star"/>|
| web（名称待定）                   |     网站快捷搭建                                         | | |
| email（名称待定）                  |     邮件功能                                                        | | |
| potencent     |     识别功能：文字识别、语音识别                                                         | https://github.com/CoderWanFeng/potencent |<img src="https://img.shields.io/github/stars/CoderWanFeng/potencent.svg" alt="github star"/> |

可以根据需求对每个模块单独引入，也可以通过`import office`方式引入所有模块。


-------------------------------------------------------------------------------

## 🏗️添砖加瓦


### 📐PR的建议

python-office欢迎任何人来添砖加瓦，贡献代码，建议提交的pr（pull request）放在一个单独的文件夹下：

- 在[contributors](https://github.com/CoderWanFeng/python-office/tree/master/contributors)文件夹中，用自己的GitHub名字建一个文件夹；
- 把自己的所有代码，都提交到这个自己的文件夹里；
- 不要改其它任何文件夹里的代码！不要改别人的代码！
- 对别人的代码有疑问，可以直接提issue。



### 🐞提供bug反馈或建议

提交问题反馈时，请务必填写和python-office代码本身有关的问题，不进行有关python学习，甚至是个人练习的知识答疑和讨论。

- [Gitee issue](https://gitee.com/CoderWanFeng/python-office/issues)
- [Github issue](https://github.com/CoderWanFeng/python-office/issues)

-------------------------------------------------------------------------------

## 🪙支持python-office

### 💳捐赠

如果你觉得python-office不错，可以捐赠请维护者喝杯咖啡~，在此表示感谢^_^。

[捐赠给项目](https://gitee.com/CoderWanFeng/python-office) 👈该项捐赠仅用于支持本项目发展使用


-------------------------------------------------------------------------------

## ⭐Star python-office

[![Stargazers over time](https://starchart.cc/CoderWanFeng/python-office.svg)](https://starchart.cc/CoderWanFeng/python-office)

## 📌联系作者


![CoderWanFeng](https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/qr-code.jpg)

## 📕拓展资料


<p align="center" id='30讲自动化办公-banner'>
    <a target="_blank" href='http://gk.link/a/10E3B'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/%E5%BC%95%E5%AF%BC%E8%B6%85%E9%93%BE%E6%8E%A5%2Fauto-work.jpg" width="100%"/>
    </a>   
</p>

<p align="center" id='100本电子书-banner'>
    <a target="_blank" href='https://mp.weixin.qq.com/s/H3us6_7wg2QspGZfGtfDZw'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/%E5%BC%95%E5%AF%BC%E8%B6%85%E9%93%BE%E6%8E%A5%2Febook.jpg" width="100%"/>
    </a>   
</p>

<p align="center" id='实战项目-banner'>
    <a target="_blank" href='http://www.python4office.cn/python-project-list/'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/%E5%BC%95%E5%AF%BC%E8%B6%85%E9%93%BE%E6%8E%A5%2Fproject.jpg" width="100%"/>
    </a>   
</p>

<p align="center" id='11个软件-banner'>
    <a target="_blank" href='https://mp.weixin.qq.com/s/uE1M8ESBQ3wJ_q-Cl1aNvg'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/%E5%BC%95%E5%AF%BC%E8%B6%85%E9%93%BE%E6%8E%A5%2Fsoft-11.jpg" width="100%"/>
    </a>   
</p>


<p align="center" id='25个学习资源-banner'>
    <a target="_blank" href='https://mp.weixin.qq.com/s/_01V8I7rVkgvIIo7ygwwQA'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/%E5%BC%95%E5%AF%BC%E8%B6%85%E9%93%BE%E6%8E%A5%2Fpy-25-source.jpg" width="100%"/>
    </a>   
</p>
